%bcond_without check

Summary:        The rust toolchain installer
Name:           rustup
Version:        1.27.1
Release:        2%{?dist}
License:        Apache-2.0 OR MIT
URL:            https://github.com/rust-lang/rustup
Source0:        https://github.com/rust-lang/rustup/archive/refs/tags/%{version}.tar.gz
# download with `cargo vendor` with cargo.toml, then package them up with `tar jzvf`
Source1:        rustup-%{version}-vendor.tar.bz2

BuildRequires:  cargo rust-toolset
BuildRequires:  pkgconfig(openssl)
Requires:       gcc

ExcludeArch: loongarch64

%description
This package provides a tool to manager user Rust toolchains, enabling you to easily switch 
between stable, beta, and nightly compilers and keep them updated.

%prep
%autosetup

%cargo_prep -V 1

%build
%cargo_build -f no-self-update

%install
%cargo_install -f no-self-update
# rustup-init and rustup are the same binary, but the binary behaves differently depending on its name.
# rustup-init should only be called once and takes care of the initial setup, including setting PATH,
# modifying .bashrc etc. 
# rustup can be used the entire time and only manages toolchains. 

# generate and install shell completions
cp -pav target/rpm/rustup-init target/rpm/rustup
target/rpm/rustup completions bash > rustup.bash
target/rpm/rustup completions fish > rustup.fish
target/rpm/rustup completions zsh > _rustup

install -Dpm 0644 rustup.bash -t %{buildroot}/%{bash_completions_dir}
install -Dpm 0644 rustup.fish -t %{buildroot}/%{fish_completions_dir}
install -Dpm 0644 _rustup -t %{buildroot}/%{zsh_completions_dir}

%if %{with check}
%check
# * skip tests that require internet access
# * skip tests for the "rustup" binary that is not built in this package
# test 'install_errors_when_rc_cannot_be_updated' should NOT be run as root!
%cargo_test -f test -- -- --skip suite::cli_exact::check_updates --skip suite::cli_ui::rustup_ui_doc_text_tests
%endif

%files
%license LICENSE-APACHE LICENSE-MIT
%doc CHANGELOG.md README.md
%{_bindir}/rustup-init
%{bash_completions_dir}/rustup.bash
%{fish_completions_dir}/rustup.fish
%{zsh_completions_dir}/_rustup

%changelog
* Thu Jul 25 2024 Pengda Dou <doupengda@loongson.cn> - 1.27.1-2
- [Type] other
- [DESC] add loongarch64 to ExcludeArch

* Tue Jul 23 2024 Upgrade Robot <upbot@opencloudos.tech> - 1.27.1-1
- Upgrade to version 1.27.1
- add script for rpm-upgrade
- no longer conflicts with rust/cargo

* Wed Jul 17 2024 Rebuild Robot <rebot@opencloudos.org> - 1.26.0-3
- [Type] bugfix
- [DESC] Rebuilt for rust-toolset, update cargo_build args

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.26.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Jul 25 2023 Wang Guodong <gordonwwang@tencent.com> - 1.26.0-1
- Upgrade to 1.26.0

* Mon Jul 17 2023 Wang Guodong <gordonwwang@tencent.com> - 1.25.1-6
- Rebuilt for rust 1.69.0

* Mon May 22 2023 Wang Guodong <gordonwwang@tencent.com> - 1.25.1-5
- add binaries which rustup will proxy.

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.25.1-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.25.1-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Dec 8 2022 Wang Guodong <gordonwwang@tencent.com> - 1.25.1-2
- rebuild for cargo-1.64.0(rust-1.64.0).

* Thu Dec 1 2022 Wang Guodong <gordonwwang@tencent.com> - 1.25.1-1
- package init.
